﻿using System;
using System.ComponentModel; // IDataErrorInfo

namespace emanual.Wpf.Apps
{
	public class OrderData : IDataErrorInfo
	{
		public string ProductName { get; set; }
		public int Price { get; set; }
		public int Quantity { get; set; }

		// 今回は使わないが、IDataErrorInfo インターフェースでは実装しなければならない
		public string Error { get { return null; } }

		// これも実装必須のプロパティで、各プロパティに対応するエラーメッセージを返す
		public string this[string propertyName]
		{
			get
			{
				string result = null;

				switch (propertyName)
				{
					case "ProductName":
						if (this.ProductName.Length < 1)
							result = "商品名をブランクにしないでください。";
						break;
					case "Price":
						if ((this.Price < 1) || (this.Price > 1000))
							result = "価格は 1,000 円以下でなければなりません。";
						break;
					case "Quantity":
						if ((this.Quantity < 1) || (this.Quantity > 100))
							result = "数量は 100 個以下でなければなりません。";
						break;
				}

				return result;
			}
		}

		// コンストラクタ
		public OrderData(string name, int price, int quantity)
		{
			this.ProductName = name;
			this.Price = price;
			this.Quantity = quantity;
		}

		// 現在のオブジェクトと同じ内容のオブジェクトを作成する
		public OrderData Clone()
		{
			return new OrderData(this.ProductName, this.Price, this.Quantity);
		}

		// オブジェクトの文字列表現を返す
		public override string ToString()
		{
			return String.Format("{0}: {1} 円 {2} 個", this.ProductName, this.Price, this.Quantity);
		}
	} // end of OrderData class
} // end of emanual.Wpf.Apps namespace
